import React from 'react';
import { SxProps } from '@mui/material/styles';
export type AuthError = {
    cause: {
        title: string;
        errorMessage: string;
    };
};
export type ErrorManagerProps = {
    /**
     * Determines whether to display a dialog, a message box, or neither
     */
    mode?: 'dialog' | 'message-box' | 'none';
    /**
     * Title to display in message box and dialog
     */
    title?: string;
    /**
     * The function to call when the close/dismiss button is clicked
     * @returns void
     */
    onClose?: () => void;
    /**
     * The error text to display
     */
    error?: string;
    /**
     * Configuration options when using mode='dialog'
     * @param {string} dialogConfig.title - The title used in the dialog header
     * @param {string} dialogConfig.dismissLabel - The label on the dismiss button.
     */
    dialogConfig?: {
        dismissLabel?: string;
        title?: string;
    };
    messageBoxConfig?: {
        title?: string;
        dismissible?: boolean;
        position?: 'top' | 'bottom';
        fontColor?: string;
        backgroundColor?: string;
        sx?: SxProps;
    };
    children?: React.ReactNode;
};
/**
 * Component that manages the display of error messages. Can be configured to display a dialog, a message box, or neither.
 *
 * @param mode determines whether to display a dialog, a message box, or neither
 * @param onClose function to call when the close/dismiss button is clicked
 * @param error error text to display
 * @param dialogConfig configuration for the error dialog
 * @param dialogConfig.title text to show in the title of the dialog
 * @param dialogConfig.dismissLabel text to show in the close button
 * @param messageBoxConfig configuration for the error message box
 * @param messageBoxConfig.dismissible whether the message box can be dismissed
 * @param messageBoxConfig.position determines whether the message box should be displayed at the top or bottom of the screen
 * @param messageBoxConfig.fontColor the font color of the text inside the message box
 * @param messageBoxConfig.backgroundColor the background color of the message box
 * @param messageBoxConfig.sx sx styles passed to the underlying root(Box) component
 *
 * @category Component
 */
declare const ErrorManager: React.FC<ErrorManagerProps>;
export default ErrorManager;
