"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContactSupportScreen = void 0;
var react_1 = __importDefault(require("react"));
var icons_material_1 = require("@mui/icons-material");
var ContactSupportScreenBase_1 = require("./ContactSupportScreenBase");
var contexts_1 = require("../../contexts");
var react_i18next_1 = require("react-i18next");
var styles_1 = require("../../styles");
var material_1 = require("@mui/material");
/**
 * Component renders a screen with contact information for support with the application.
 * Contact information is pulled from the context passed into the workflow.
 *
 * @param icon the icon to display in the header
 * @param emailSupportTitle text to display as the contact support title
 * @param emailSupportContent content to display as the contact support content
 * @param phoneSupportTitle text to display as the phone support title
 * @param phoneSupportContent content to display as the phone support content
 * @param contactEmail to display the contact email
 * @param contactPhone to display contact phone number
 * @param dismissButtonLabel to display label for the button
 * @param onDismiss function to call when user clicks button
 * @param WorkflowCardBaseProps props that will be passed to the WorkflowCard component
 * @param WorkflowCardHeaderProps props that will be passed to the WorkflowCardHeader component
 * @param WorkflowCardInstructionProps props that will be passed to the WorkflowCardInstructions component
 * @param WorkflowCardActionsProps props that will be passed to the WorkflowCardActions component
 *
 * @category Component
 */
var ContactSupportScreen = function (props) {
    var t = (0, react_i18next_1.useTranslation)().t;
    var _a = (0, contexts_1.useAuthContext)(), navigate = _a.navigate, routeConfig = _a.routeConfig;
    var _b = props.contactEmail, contactEmail = _b === void 0 ? 'something@email.com' : _b, _c = props.contactPhone, contactPhone = _c === void 0 ? '1-800-123-4567' : _c;
    var defaultEmailSupportContent = function () { return (react_1.default.createElement(material_1.Typography, { variant: "body1" }, "".concat(t('bluiAuth:CONTACT_SUPPORT.SUPPORT_MESSAGE')),
        react_1.default.createElement(material_1.Typography, { variant: "button", sx: __assign(__assign({}, styles_1.LinkStyles), { fontSize: 'inherit' }), component: "a", href: "mailto:".concat(contactEmail !== null && contactEmail !== void 0 ? contactEmail : '') }, contactEmail), ".")); };
    var defaultPhoneSupportContent = function () { return (react_1.default.createElement(material_1.Typography, { variant: "body1" }, "".concat(t('bluiAuth:CONTACT_SUPPORT.TECHNICAL_ASSISTANCE')),
        react_1.default.createElement(material_1.Typography, { variant: "button", sx: __assign(__assign({}, styles_1.LinkStyles), { fontSize: 'inherit' }), component: "a", href: "tel:".concat(contactPhone !== null && contactPhone !== void 0 ? contactPhone : '') }, contactPhone), ".")); };
    var _d = props.icon, icon = _d === void 0 ? react_1.default.createElement(icons_material_1.ChatBubbleOutline, { color: 'primary', sx: { fontSize: 70 } }) : _d, _e = props.emailSupportTitle, emailSupportTitle = _e === void 0 ? t('bluiAuth:CONTACT_SUPPORT.GENERAL_QUESTIONS') : _e, _f = props.emailSupportContent, emailSupportContent = _f === void 0 ? defaultEmailSupportContent : _f, _g = props.phoneSupportTitle, phoneSupportTitle = _g === void 0 ? t('bluiAuth:CONTACT_SUPPORT.EMERGENCY_SUPPORT') : _g, _h = props.phoneSupportContent, phoneSupportContent = _h === void 0 ? defaultPhoneSupportContent : _h, _j = props.dismissButtonLabel, dismissButtonLabel = _j === void 0 ? t('bluiCommon:ACTIONS.OKAY') : _j, onDismiss = props.onDismiss, WorkflowCardHeaderProps = props.WorkflowCardHeaderProps, WorkflowCardActionsProps = props.WorkflowCardActionsProps, otherContactSupportProps = __rest(props, ["icon", "emailSupportTitle", "emailSupportContent", "phoneSupportTitle", "phoneSupportContent", "dismissButtonLabel", "onDismiss", "WorkflowCardHeaderProps", "WorkflowCardActionsProps"]);
    var workflowCardHeaderProps = __assign({ title: t('bluiAuth:USER_MENU.CONTACT_US') }, WorkflowCardHeaderProps);
    var workflowCardActionsProps = __assign(__assign({ nextLabel: t('bluiCommon:ACTIONS.OKAY'), showNext: true, canGoNext: true, fullWidthButton: true }, WorkflowCardActionsProps), { onNext: function () {
            var _a;
            navigate(routeConfig.LOGIN);
            (_a = WorkflowCardActionsProps === null || WorkflowCardActionsProps === void 0 ? void 0 : WorkflowCardActionsProps.onNext) === null || _a === void 0 ? void 0 : _a.call(WorkflowCardActionsProps);
        } });
    return (react_1.default.createElement(ContactSupportScreenBase_1.ContactSupportScreenBase, __assign({ WorkflowCardHeaderProps: workflowCardHeaderProps, WorkflowCardActionsProps: workflowCardActionsProps, icon: icon, emailSupportTitle: emailSupportTitle, emailSupportContent: emailSupportContent, phoneSupportTitle: phoneSupportTitle, phoneSupportContent: phoneSupportContent, contactEmail: contactEmail, contactPhone: contactPhone, dismissButtonLabel: dismissButtonLabel, onDismiss: onDismiss }, otherContactSupportProps)));
};
exports.ContactSupportScreen = ContactSupportScreen;
