"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ForgotPasswordScreenBase = void 0;
var react_1 = __importStar(require("react"));
var TextField_1 = __importDefault(require("@mui/material/TextField"));
var components_1 = require("../../components");
var SuccessScreen_1 = require("../SuccessScreen");
var ErrorManager_1 = __importDefault(require("../../components/Error/ErrorManager"));
/**
 * Component renders a screen with forgot password for support with the application.
 *
 * @param emailLabel label for the email field
 * @param initialEmailValue initial value for the email text field
 * @param emailValidator function used to test the input for valid formatting
 * @param canGoNext boolean or function that indicates whether the next button should be enabled
 * @param showSuccessScreen used to determine whether to show a success screen after the form is submitted
 * @param slots used for ForgotPasswordScreen SuccessScreen
 * @param slotProps applied to slot from SuccessScreen
 * @param WorkflowCardBaseProps props that will be passed to the WorkflowCard component
 * @param WorkflowCardHeaderProps props that will be passed to the WorkflowCardHeader component
 * @param WorkflowCardInstructionProps props that will be passed to the WorkflowCardInstructions component
 * @param WorkflowCardActionsProps props that will be passed to the WorkflowCardActions component
 * @param errorDisplayConfig configuration for customizing how errors are displayed
 * @param emailTextFieldProps props to pass to the email field.
 *
 * @category Component
 */
var ForgotPasswordScreenBase = function (props) {
    var _a, _b;
    var _c = (0, react_1.useState)((_a = props.initialEmailValue) !== null && _a !== void 0 ? _a : ''), emailInput = _c[0], setEmailInput = _c[1];
    var emailLabel = props.emailLabel, _d = props.initialEmailValue, initialEmailValue = _d === void 0 ? '' : _d, 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    _e = props.emailValidator, 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    emailValidator = _e === void 0 ? function (email) { return true; } : _e, slots = props.slots, _f = props.slotProps, slotProps = _f === void 0 ? {} : _f, showSuccessScreen = props.showSuccessScreen, errorDisplayConfig = props.errorDisplayConfig, emailTextFieldProps = props.emailTextFieldProps;
    var cardBaseProps = props.WorkflowCardBaseProps || {};
    var headerProps = props.WorkflowCardHeaderProps || {};
    var instructionsProps = props.WorkflowCardInstructionProps || {};
    var actionsProps = props.WorkflowCardActionsProps || {};
    var validateEmail = function () { return typeof emailValidator(initialEmailValue) !== 'string'; };
    var _g = (0, react_1.useState)(validateEmail), isEmailValid = _g[0], setIsEmailValid = _g[1];
    var _h = (0, react_1.useState)(!validateEmail() ? emailValidator(initialEmailValue) : ''), emailError = _h[0], setEmailError = _h[1];
    var _j = (0, react_1.useState)((_b = initialEmailValue !== '') !== null && _b !== void 0 ? _b : validateEmail), shouldValidateEmail = _j[0], setShouldValidateEmail = _j[1];
    var handleEmailInputChange = (0, react_1.useCallback)(function (email) {
        setEmailInput(email);
        var emailValidatorResponse = emailValidator(email);
        setIsEmailValid(typeof emailValidatorResponse === 'boolean' ? emailValidatorResponse : false);
        setEmailError(typeof emailValidatorResponse === 'string' ? emailValidatorResponse : '');
    }, [emailValidator]);
    var handleOnNext = function () {
        var onNext = actionsProps.onNext;
        if (onNext) {
            onNext({ email: emailInput });
        }
    };
    var getSuccessScreen = function (_props, SuccessScreen) { return (SuccessScreen ? SuccessScreen(_props) : react_1.default.createElement(SuccessScreen_1.SuccessScreenBase, __assign({}, _props))); };
    return (react_1.default.createElement(react_1.default.Fragment, null, showSuccessScreen ? (getSuccessScreen((slotProps === null || slotProps === void 0 ? void 0 : slotProps.SuccessScreen) || {}, slots === null || slots === void 0 ? void 0 : slots.SuccessScreen)) : (react_1.default.createElement(components_1.WorkflowCard, __assign({}, cardBaseProps),
        react_1.default.createElement(components_1.WorkflowCardHeader, __assign({}, headerProps)),
        react_1.default.createElement(components_1.WorkflowCardInstructions, __assign({}, instructionsProps)),
        react_1.default.createElement(components_1.WorkflowCardBody, null,
            react_1.default.createElement(ErrorManager_1.default, __assign({}, errorDisplayConfig),
                react_1.default.createElement(TextField_1.default, __assign({ id: "email", label: emailLabel, fullWidth: true, value: emailInput, variant: "filled", error: shouldValidateEmail && !isEmailValid, helperText: shouldValidateEmail && emailError }, emailTextFieldProps, { onBlur: function (e) {
                        // eslint-disable-next-line no-unused-expressions
                        (emailTextFieldProps === null || emailTextFieldProps === void 0 ? void 0 : emailTextFieldProps.onBlur) && emailTextFieldProps.onBlur(e);
                        setShouldValidateEmail(true);
                    }, onChange: function (evt) {
                        // eslint-disable-next-line no-unused-expressions
                        (emailTextFieldProps === null || emailTextFieldProps === void 0 ? void 0 : emailTextFieldProps.onChange) && emailTextFieldProps.onChange(evt);
                        handleEmailInputChange(evt.target.value);
                    }, onKeyUp: function (e) {
                        if (e.key === 'Enter' &&
                            ((emailInput.length > 0 && isEmailValid) || actionsProps.canGoNext))
                            handleOnNext();
                    } })))),
        react_1.default.createElement(components_1.WorkflowCardActions, __assign({}, actionsProps, { canGoNext: emailInput.length > 0 && isEmailValid && actionsProps.canGoNext, onNext: handleOnNext }))))));
};
exports.ForgotPasswordScreenBase = ForgotPasswordScreenBase;
